@@ -5,46 +5,38 @@ use warnings;
 use v5.14.0;
 use AnyEvent;
 use AnyEvent::WebSocket::Client;
-use Mojo::JSON qw(j);
-use Data::Dumper;
+use JSON::PP;
 use DDP;
 
-$Data::Dumper::Indent = 1;
-
 my $client = AnyEvent::WebSocket::Client->new(ssl_no_verify => 1);
-my $done = AnyEvent->condvar;
 
 my $params = {
     'Type'      => 'Admin',
     'Request'   => 'Login',
     'Params'    => {
         'AuthTag'  => 'user-admin',
-        'Password' => 'bac2d0de80a99bb499c442326a617788'
+        'Password' => $ENV{JUJU_PASS}
     }
 };
 
-my $ws = $client->connect("wss://10.0.3.1:17070/")->recv;
+my $ws = $client->connect("wss://localhost:17070/")->recv;
 my $res;
 $ws->on(
     each_message => sub {
-
+      my ($c, $m) = @_;
         # $connection is the same connection object
         # $message isa AnyEvent::WebSocket::Message
-        print Dumper(pop->decoded_body);
+        $done->send(decode_json($m->decoded_body));
     }
 );
 
-# handle a closed connection...
-$ws->on(
-    finish => sub {
+my $done = AnyEvent->condvar;
+$ws->send(encode_json($params));
+p($done->recv);
+
+$done = AnyEvent->condvar;
+$ws->send(encode_json({"Type" => "Client", "Request" => "FullStatus"}));
+p($done->recv);
 
-        # $connection is the same connection object
-        my ($connection) = @_;
-        $done->send;
-    }
-);
-$ws->send(j($params));
-$ws->send(j({"Type" => "Client", "Request" => "EnvironmentInfo"}));
 $ws->close;
-$done->recv;
 
